import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';

import 'linearProgressIndicator.dart';

class Progress extends StatefulWidget {
  const Progress({super.key});

  @override
  State<Progress> createState() => _ProgressState();
}

class _ProgressState extends State<Progress> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  LeaderBoardModel? currentUser = LeaderBoardModel();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: EdgeInsets.only(top: 15.0),
        decoration: const BoxDecoration(
            color: Color.fromARGB(255, 244, 244, 244),
            border: Border(
              bottom: BorderSide(
                color: Color.fromARGB(255, 228, 228, 228),
                width: 1.0,
              ),
            )),
        padding: const EdgeInsets.only(
            left: 20.0, right: 20.0, top: 25.0, bottom: 35.0),
        child: Column(
          children: [
            Padding(
                padding: const EdgeInsets.only(bottom: 5.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    const Text(
                      "Progress",
                      style: TextStyle(
                          fontSize: 19.0,
                          fontWeight: FontWeight.bold,
                          fontFamily: 'PlusJakartaSans-SemiBold'),
                    ),
                    Row(children: [
                      Image.asset(
                        "assets/icons/bolt.png",
                        package: "progamification",
                        width: 55,
                        height: 55,
                      ),
                      Text(currentUser!.score.toString(),
                          style: const TextStyle(
                              fontSize: 18.0,
                              fontFamily: 'PlusJakartaSans-SemiBold',
                              fontWeight: FontWeight.w600))
                    ]),
                  ],
                )),
            LinearGradientProgressIndicator(
              value: double.parse(
                  (leaderBoardController.userRewards["progress"]) as String),
              backgroundColor: const Color(0xffFAF5EA),
              gradientColors: const [
                Color(0xffFDB300),
                Color(0xffFC8F00),
              ],
              borderColor: const Color(0xffFC9300),
            )
          ],
        ));
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}
